## Proposed changes

Describe the big picture of your changes here to communicate to the maintainers 
why we should accept this pull request. If it fixes a bug or resolves a feature 
request, be sure to link to that issue.

## Types of changes

What types of changes does your code introduce to LIVVkit?
_Put an `x` in the boxes that apply_

- [ ] Bugfix (non-breaking change which fixes an issue)
- [ ] New feature (non-breaking change which adds functionality)
- [ ] Breaking change (fix or feature that would cause existing functionality to 
      not work as expected)

## Checklist
🚨Please review the [guidelines for contributing](../docs/CONTRIBUTING.rst) to 
this repository.

_Put an `x` in the boxes that apply. You can also fill these out after creating 
the PR. If you're unsure about any of them, don't hesitate to ask. We're here to 
help! This is simply a reminder of what we are going to look for before merging 
your code._

- [ ] Make sure you are requesting to **pull a topic/feature/bugfix branch** (right side). Don't request your master!
- [ ] Make sure you are making a pull request against the `develop` branch (left side). Also you should start *your branch* off *our* `develop`.
- [ ] Created tests which fail without the change (if possible)
- [ ] I have added necessary documentation (if appropriate)
- [ ] All tests passing



## Further comments

If this is a relatively large or complex change, kick off the discussion by 
explaining why you chose the solution you did and what alternatives you 
considered, etc...



## Thank you!